@@ -220,5 +220,9 @@ def get_hostname():
     return run('hostname')
 
 
-
-
+def daemon(cmd, *args, **kwargs):
+    use_sudo = kwargs.pop('use_sudo', False)
+    if use_sudo:
+        sudo("sh -c '((nohup %s > /dev/null 2> /dev/null) & )'" % cmd, pty=False, *args, **kwargs)
+    else:
+        run("sh -c '((nohup %s > /dev/null 2> /dev/null) & )'" % cmd, pty=False, *args, **kwargs)
